import { PrivKey } from '@aldea/core';
import { pino } from 'pino';
import pretty from 'pino-pretty';
// Default configuration
const defaults = {
    listen_addrs: [
        '/ip4/0.0.0.0/tcp/41410'
    ],
    peer_key: PrivKey.fromRandom().toHex(),
    nat_enabled: false,
};
/**
 * Self invoking expression that exports global config object.
 */
export const config = (() => {
    return Object.entries(defaults).reduce((config, [key, val]) => {
        const env = process.env[key.toUpperCase()];
        if (typeof env === 'undefined') {
            config[key] = val;
        }
        else if (Array.isArray(val)) {
            config[key] = env.split(',').map(s => s.trim());
        }
        else if (typeof val === 'number') {
            config[key] = Number(env);
        }
        else {
            config[key] = env;
        }
        return config;
    }, {});
})();
/**
 * Global shared logger stream
 */
// @ts-ignore
export const logStream = pretty({ colorize: true });
/**
 * Global logger instance.
 */
export const logger = pino(logStream);
